Documentation
¶
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
func NewClient ¶
func NewClient(cfg ClientConfig) Client
type ClientConfig ¶
type Implementation ¶
type Implementation struct {
// Source is the canonical location of the source code.
Source string
// Version is the version number of the implementation.
Version string
// Revision is the precise git revision of the implementation.
Revision string
}
Implementation identifies the implementation of the Internet Computer.
type Status ¶
type Status struct {
// Identifies the interface version supported.
Version string
// Impl describes the implementation of the Internet Computer.
Impl *Implementation
// The public key (a DER-encoded BLS key) of the root key of this Internet Computer instance.
RootKey []byte
}
Status describes various status fields of the Internet Computer.
func (*Status) UnmarshalCBOR ¶
Click to show internal directories.
Click to hide internal directories.